//! This module implements parsers to extract hyperlinks
//! image elements from HTML text input.

pub mod html;
pub mod parse_html;
